@@ -1,8 +1,8 @@
 import re
-from os import PathLike
 from io import BytesIO, BufferedReader
+from os import PathLike
 from pathlib import Path
-from typing import Any, Union, TYPE_CHECKING, BinaryIO, Dict, Optional, Literal, Callable, Tuple, Sequence
+from typing import Any, Union, TYPE_CHECKING, BinaryIO, Dict, Optional, Literal, Callable
 
 from nonebot.adapters import Bot as BaseBot
 from nonebot.message import handle_event
@@ -294,9 +294,18 @@ class Bot(BaseBot, ApiClient):
 
         # type & content
         if isinstance(message, Message):
-            params["type"], params["content"] = await MessageSerializer(message).serialize()
+            new_message = Message()
+            # 提取message中的quote消息段
+            for seg in message:
+                if seg.type == 'quote':
+                    if not quote:
+                        quote = seg.data["msg_id"]
+                else:
+                    new_message.append(seg)
+
+            params["type"], params["content"] = MessageSerializer(new_message).serialize()
         elif isinstance(message, MessageSegment):
-            params["type"], params["content"] = await MessageSerializer(Message(message)).serialize()
+            params["type"], params["content"] = MessageSerializer(Message(message)).serialize()
         else:
             params["type"], params["content"] = 1, message
 
